//
//  igViewController.m
//  SQLiteData_ObjC
//
//  Created by Torrey Betts on 04/23/13.
//  Copyright (c) 2013 Infragistics. All rights reserved.
//

#import "igViewController.h"
#import <sqlite3.h>
#import <IG/IG.h>

@interface EmployeeObject : NSObject

@property (nonatomic, retain) NSString *name;
@property (nonatomic, retain) NSString *email;
@property (nonatomic, retain) NSString *department;

@end

@implementation EmployeeObject
@synthesize department, email, name;
@end

@interface igViewController ()
{
    NSMutableArray *_sqliteData;
    IGGridView *_gridView;
    IGGridViewDataSourceHelper *_dsh;
}

@end

@implementation igViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
    self.view.backgroundColor = [UIColor whiteColor];

    [self getSQLiteData:[self getDatabasePath]];

    _gridView = [[IGGridView alloc] initWithFrame:self.view.bounds style:IGGridViewStyleDefault];
    _gridView.autoresizingMask = UIViewAutoresizingFlexibleHeight|UIViewAutoresizingFlexibleWidth;
    _gridView.headerHeight = 0;
    [self.view addSubview:_gridView];

    _dsh = [[IGGridViewDataSourceHelper alloc] init];
    _dsh.data = _sqliteData;
    _dsh.groupingKey = @"department";

    _gridView.dataSource = _dsh;
}

-(NSString *)getDatabasePath
{
    return [[[NSBundle mainBundle] resourcePath] stringByAppendingPathComponent:@"BasicData.db"];
}

-(void)getSQLiteData:(NSString *)dbPath
{
    _sqliteData = [[NSMutableArray alloc] init];

    sqlite3 *database;
    if (sqlite3_open([dbPath UTF8String], &database) == SQLITE_OK) {

        const char *sql = "select Name, Email, Department from Employees";
        sqlite3_stmt *selectStatement;
        if(sqlite3_prepare_v2(database, sql, -1, &selectStatement, NULL) == SQLITE_OK) {

            while(sqlite3_step(selectStatement) == SQLITE_ROW) {
                EmployeeObject *employeeObject = [[EmployeeObject alloc] init];
                employeeObject.name = [NSString stringWithUTF8String:(char *)sqlite3_column_text(selectStatement, 0)];
                employeeObject.email = [NSString stringWithUTF8String:(char *)sqlite3_column_text(selectStatement, 1)];
                employeeObject.department = [NSString stringWithUTF8String:(char *)sqlite3_column_text(selectStatement, 2)];
                [_sqliteData addObject:employeeObject];
            }
        }
    }

    sqlite3_close(database);
}

@end